#!/usr/bin/env python

"A very simple example application."

import WebStack.Generic
from XSLForms.Resources.WebResources import \
    XSLFormsResource, input, output, resources, prepare_resources as xslforms_prepare_resources
import os

# Site map imports.

from WebStack.Resources.ResourceMap import MapResource
from WebStack.Resources.Selectors import EncodingSelector
from WebStack.Resources.Static import DirectoryResource

# Configuration settings.

encoding = "utf-8"

# Resource classes.

class VerySimpleResource(XSLFormsResource):

    "A very simple resource providing a hierarchy of editable fields."

    resource_dir = resources(__file__)
    template_resources = {
        #"structure" : output("structure_template.xhtml")
        #"structure" : output("structure_multivalue_template.xhtml")
        "structure" : output("structure_multivalue_label_template.xhtml")
        }
    init_resources = {
        #"structure" : input("structure_template.xhtml")
        #"structure" : input("structure_multivalue_template.xhtml")
        "structure" : input("structure_multivalue_label_template.xhtml")
        }
    transform_resources = {
        "comments" : ["structure_comments.xsl"]
        }
    document_resources = {
        #"types" : "structure_types.xml"
        "types" : "structure_types_label.xml",
        "translations" : "translations.xml"
        }
    in_page_resources = {
        "comments" : ("structure", "structure_output_comments.xsl", "comment-node")
        }

    def select_activity(self, trans, form):
        form.set_activity("structure")

    def respond_to_input(self, trans, form):

        # Add and remove elements according to the selectors found.

        selectors = form.get_selectors()
        self.remove_elements(selectors.get("remove2"))
        self.add_elements(selectors.get("add2"), "subitem")
        self.remove_elements(selectors.get("remove"))
        self.add_elements(selectors.get("add"), "item")

    def init_document(self, trans, form):

        # Transform, adding enumerations/ranges.

        types_xml = self.prepare_document("types")
        XSLFormsResource.init_document(self, trans, form, references={"type" : types_xml})

    def respond_to_document(self, trans, form):

        # Add the comments.

        comments_xsl_list = self.prepare_transform("comments")
        form.set_document(
            self.get_result(comments_xsl_list, form.get_document())
            )

    def create_output(self, trans, form):

        # Complete the response.

        stylesheet_parameters = {}

        try:
            stylesheet_parameters["locale"] = trans.get_content_languages()[0]
        except IndexError:
            pass

        XSLFormsResource.create_output(self, trans, form,
            stylesheet_parameters=stylesheet_parameters,
            references={
                "translations" : self.prepare_document("translations")
            })

# Site map initialisation.

def get_site():

    "Return a simple Web site resource."

    # Get the main resource and the directory used by the application.

    very_simple_resource = VerySimpleResource()
    directory = very_simple_resource.resource_dir

    # Make a simple Web site.

    resource = MapResource({
        # Static resources:
        "scripts" : DirectoryResource(os.path.join(directory, "scripts"), {"js" : "text/javascript"}),
        # Main page and in-page resources:
        None : very_simple_resource
        })

    return EncodingSelector(resource, encoding)

# Resource preparation ahead of time - useful for making installations.

def prepare_resources():
    for cls in [VerySimpleResource]:
        xslforms_prepare_resources(cls)

# vim: tabstop=4 expandtab shiftwidth=4
